@@ -5,21 +5,16 @@ from llama_index.data_structs.data_structs import (
     IndexGraph,
     IndexList,
     KeywordTable,
-    Node,
-    QdrantIndexStruct,
-    SimpleIndexDict,
-    WeaviateIndexStruct,
 )
+from llama_index.data_structs.node import Node, NodeWithScore
 from llama_index.data_structs.table import StructDatapoint
 
 __all__ = [
     "Node",
+    "NodeWithScore",
     "IndexGraph",
     "KeywordTable",
     "IndexList",
     "IndexDict",
-    "SimpleIndexDict",
-    "WeaviateIndexStruct",
-    "QdrantIndexStruct",
     "StructDatapoint",
 ]
